@@ -17,7 +17,7 @@ THRASHING_TIMEOUT = getattr(settings, 'SENTRY_THRASHING_TIMEOUT', 60)
 THRASHING_LIMIT = getattr(settings, 'SENTRY_THRASHING_LIMIT', 10)
 
 FILTERS = getattr(settings, 'SENTRY_FILTERS', filter(None, (
-    getattr(settings, 'HAYSTACK_SEARCH_ENGINE', 'dummy') != 'dummy' and 'sentry.filters.SearchFilter' or None,
+    getattr(settings, 'HAYSTACK_SEARCH_ENGINE', None) and 'sentry.filters.SearchFilter' or None,
     'sentry.filters.StatusFilter',
     'sentry.filters.LoggerFilter',
     'sentry.filters.LevelFilter',
