@@ -1,4 +1,5 @@
 import logging
+import sys
 import urllib
 import urllib2
 import uuid
@@ -75,6 +76,8 @@ def transform(value):
             return str(value)
         except:
             return to_unicode(value)
+    elif hasattr(value, '__sentry__'):
+        return value.__sentry__()
     elif not isinstance(value, (int, bool)) and value is not None:
         # XXX: we could do transform(repr(value)) here
         return to_unicode(value)
@@ -82,11 +85,14 @@ def transform(value):
 
 def to_unicode(value):
     try:
-        value = force_unicode(value)
+        value = unicode(force_unicode(value))
     except (UnicodeEncodeError, UnicodeDecodeError):
         value = '(Error decoding value)'
     except Exception: # in some cases we get a different exception
-        value = force_unicode(type(value))
+        try:
+            value = str(repr(type(value)))
+        except Exception:
+            value = '(Error decoding value)'
     return value
 
 def get_installed_apps():
@@ -169,3 +175,33 @@ def urlread(url, get={}, post={}, headers={}, timeout=None):
     except:
         response = urllib2.urlopen(req, urllib.urlencode(post)).read()
     return response
+
+def get_versions(module_list=None):
+    if not module_list:
+        module_list = settings.INSTALLED_APPS + ['django']
+
+    ext_module_list = set()
+    for m in module_list:
+        parts = m.split('.')
+        ext_module_list.update('.'.join(parts[:idx]) for idx in xrange(1, len(parts)+1))
+
+    versions = {}
+    for module_name in ext_module_list:
+        __import__(module_name)
+        app = sys.modules[module_name]
+        if hasattr(app, 'get_version'):
+            get_version = app.get_version
+            if callable(get_version):
+                version = get_version()
+            else:
+                version = get_version
+        elif hasattr(app, 'VERSION'):
+            version = app.VERSION
+        elif hasattr(app, '__version__'):
+            version = app.__version__
+        else:
+            continue
+        if isinstance(version, (list, tuple)):
+            version = '.'.join(str(o) for o in version)
+        versions[module_name] = version
+    return versions
\ No newline at end of file
