@@ -86,7 +86,7 @@ var Sentry = {};
             remove = true;
         } 
         $.ajax({
-            url: SENTRY_JS_API_URL,
+            url: Sentry.options.apiUrl,
             type: 'post',
             dataType: 'json',
             data: {
@@ -277,9 +277,9 @@ var Sentry = {};
             }
             return cookieValue;
         }
-        if (!(/^http:.*/.test(settings.url) || /^https:.*/.test(settings.url))) {
+        if (!(/^http:.*/.test(settings.url) || (/^https:.*/.test(settings.url)))) {
             // Only send the token to relative URLs i.e. locally.
             xhr.setRequestHeader("X-CSRFToken", getCookie('csrftoken'));
         }
     });
-});
+}());
